WORC.tools package — WORC 2.1.1 documentation

# WORC.tools package

## Submodules

## WORC.tools.Elastix module

class `WORC.tools.Elastix.` `Elastix`

  Bases: `object`

  `addchangeorder`()
  `create_bbox`(seg, pad=[2, 25, 25])

    Create a bounding box around an input segmentation with a certain padding

  `create_network`(nettype)
  `execute`()
  `getparametermap`(model='affine', size=(512, 512, 128))

## WORC.tools.Evaluate module

class `WORC.tools.Evaluate.` `Evaluate`(label_type, ensemble=50, scores='percentages', network=None, features=None, fastr_plugin='ProcessPoolExecution', name='Example')

  Bases: `object`

  `create_network`()

    Add evaluate components to network.

  `execute`()

    Execute the network through the fastr.network.execute command.

  `set`(estimator=None, pinfo=None, images=None, segmentations=None, config=None, features=None, sink_data={})

    Set the sources and sinks based on the provided attributes.

## WORC.tools.Transformix module

class `WORC.tools.Transformix.` `Transformix`

  Bases: `object`

  `create_network`()
  `execute`()

## Module contents